@@ -6,6 +6,8 @@
 */
 
 #include "groupmanagementdialogtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "groupmanagementdialog.h"
 #include "groupmanagementwidget.h"
 #include <QDialogButtonBox>
@@ -23,13 +25,13 @@ void GroupManagementDialogTest::shouldHaveDefaultValues()
 {
     GroupManagementDialog w;
     QVERIFY(!w.windowTitle().isEmpty());
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
 
-    auto mGroupManagementWidget = w.findChild<GroupManagementWidget *>(QStringLiteral("mGroupManagementWidget"));
+    auto mGroupManagementWidget = w.findChild<GroupManagementWidget *>(u"mGroupManagementWidget"_s);
     QVERIFY(mGroupManagementWidget);
 
-    auto buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonBox"));
+    auto buttonBox = w.findChild<QDialogButtonBox *>(u"buttonBox"_s);
     QVERIFY(buttonBox);
 }
 
